Module event

Module event 

Structs

BalanceDecrease
BalanceIncrease
BlockChainEvent
EndOfMarketOrderEvent
Fake event injected at the end of the contract call which created a market order.
FeesClaimedEvent
NewTx
NonceChangeEvent
Event emitted when a nonce change occurs for a contract.
OrderBookBlacklistEvent
OrderBookConfigEvent
Event emitted at initialization that provides information about the order book.
OrderBookRegistered
OrderBookSymbolsEvent
Event emitted when the base and quote symbols are set.
OrderBookWhitelistEvent
OrderCancelledEvent
Event emitted when an order is cancelled.
OrderCreatedEvent
Event emitted when a new order is added to the order book.
OrderMatchedEvent
Event emitted when two orders are matched and executed.
PauseEvent
Session
SessionCreated
SessionRevoked
TradeAccountReferer
TradeAccountRegistered
UnpauseEvent
WithdrawSettledTradeEvent
Event emitted when a trader receives their settled balance.

Enums

CancellationReason
Event
EventV1
Identity

Type Aliases

OnChainTimeStamp
Alias for on-chain timestamp. Represented in seconds since UNIX EPOCH.
SeenTimeStamp
Alias for timestamp when event was seen by the indexer. Represented in nanoseconds since UNIX EPOCH.